<node_directory>/
├── README.md          # Describes the background, features, and usage of the Agent
├── pyproject.toml     # Python package dependencies
├── agent/
│   └── main.py        # Main code of the Agent
    ├── configs/
│       └── *.yml          # Configuration file directory
└── tests/
    └── test_main.py   # Functional test code
